aboutsummaryrefslogtreecommitdiffstats
path: root/AST.h
diff options
context:
space:
mode:
authorLiana Husikyan <liana@ethdev.com>2015-03-25 20:58:15 +0800
committerLiana Husikyan <liana@ethdev.com>2015-03-25 21:20:13 +0800
commit8f747aab0f977e62c344f57fe922ba6b0fda3a64 (patch)
treef90a3d47e3b0dafcbd4f16094edf7f6bf69de1d5 /AST.h
parent9986b072ad471908df4402ef860e58e331035948 (diff)
downloaddexon-solidity-8f747aab0f977e62c344f57fe922ba6b0fda3a64.tar
dexon-solidity-8f747aab0f977e62c344f57fe922ba6b0fda3a64.tar.gz
dexon-solidity-8f747aab0f977e62c344f57fe922ba6b0fda3a64.tar.bz2
dexon-solidity-8f747aab0f977e62c344f57fe922ba6b0fda3a64.tar.lz
dexon-solidity-8f747aab0f977e62c344f57fe922ba6b0fda3a64.tar.xz
dexon-solidity-8f747aab0f977e62c344f57fe922ba6b0fda3a64.tar.zst
dexon-solidity-8f747aab0f977e62c344f57fe922ba6b0fda3a64.zip
tests for external types
Diffstat (limited to 'AST.h')
-rw-r--r--AST.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/AST.h b/AST.h
index 937c2cea..0d3ef857 100644
--- a/AST.h
+++ b/AST.h
@@ -422,9 +422,9 @@ public:
void checkTypeRequirements();
/// @returns the external signature of the function
/// That consists of the name of the function followed by the external types of the
/// arguments separated by commas all enclosed in parentheses without any spaces.
- std::string externalSignature() const;
+ std::string externalSignature(bool isExternalCall = false) const;
private:
bool m_isConstructor;
@@ -422,9 +422,9 @@ public:
void checkTypeRequirements();
/// @returns the external signature of the function
- /// That consists of the name of the function followed by the external types of the
+ /// That consists of the name of the function followed by the types(external types if isExternalCall) of the
/// arguments separated by commas all enclosed in parentheses without any spaces.